==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogQualityVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-工程质量检查、验收情况（质检员）
 *
 * @author baipengyan
 */
public class ProjectLogQualityVO extends BaseVO {
	private static final long serialVersionUID = 3288674363383376580L;

	private Long personId; // 个人日志id
	private Long qualityId; // 工作类别id
	private String qualityName; // 工作类别名称
	private String qualityCode; // 工作类别编码
	private String qualityMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getQualityId() {
		return qualityId;
	}

	public void setQualityId(Long qualityId) {
		this.qualityId = qualityId;
	}

	public String getQualityName() {
		return qualityName;
	}

	public void setQualityName(String qualityName) {
		this.qualityName = qualityName;
	}

	public String getQualityCode() {
		return qualityCode;
	}

	public void setQualityCode(String qualityCode) {
		this.qualityCode = qualityCode;
	}

	public String getQualityMemo() {
		return qualityMemo;
	}

	public void setQualityMemo(String qualityMemo) {
		this.qualityMemo = qualityMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogQualityVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-工程质量检查、验收情况（质检员）
 *
 * @author baipengyan
 */
public class ProjectLogQualityVO extends BaseVO {
	private static final long serialVersionUID = 3288674363383376580L;

	private Long personId; // 个人日志id
	private Long qualityId; // 工作类别id
	private String qualityName; // 工作类别名称
	private String qualityCode; // 工作类别编码
	private String qualityMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getQualityId() {
		return qualityId;
	}

	@ReferDeserialTransfer
	public void setQualityId(Long qualityId) {
		this.qualityId = qualityId;
	}

	public String getQualityName() {
		return qualityName;
	}

	public void setQualityName(String qualityName) {
		this.qualityName = qualityName;
	}

	public String getQualityCode() {
		return qualityCode;
	}

	public void setQualityCode(String qualityCode) {
		this.qualityCode = qualityCode;
	}

	public String getQualityMemo() {
		return qualityMemo;
	}

	public void setQualityMemo(String qualityMemo) {
		this.qualityMemo = qualityMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
